@@ -19,7 +19,7 @@ NULL
 # #'@importFrom testthat test_that expect_equal
 # NULL
 
-#' @importFrom stats anova as.formula confint cor.test fisher.test ks.test mad median na.omit p.adjust pairwise.t.test pnorm power.prop.test power.t.test qnorm quantile rpois sd wilcox.test t.test var.test
+#' @importFrom stats anova as.formula confint cor.test fisher.test ks.test mad median na.omit p.adjust pairwise.t.test pnorm power.prop.test power.t.test qnorm quantile rpois sd wilcox.test t.test var.test predict SSmicmen coef
 NULL
 
 #' @import ggplot2
@@ -34,6 +34,11 @@ NULL
 #' @importFrom utils data
 NULL
 
+#' @importFrom broom tidy
+NULL
+
+#' @importFrom rlist list.append
+NULL 
 
 #' @importFrom forcats fct_lump_n fct_drop
 NULL
\ No newline at end of file
